@@ -222,11 +222,20 @@ launcher_launch (Launcher  *launcher,
 	
 	if (panel_global_config_get_drawer_auto_close ()) {
 		PanelToplevel *toplevel;
+		PanelToplevel *parent;
 
 		toplevel = PANEL_WIDGET (launcher->button->parent)->toplevel;
 
-		if (panel_toplevel_get_is_attached (toplevel)) 
+		if (panel_toplevel_get_is_attached (toplevel)) {
+			parent = panel_toplevel_get_attach_toplevel (toplevel);
+
+			while (panel_toplevel_get_is_attached (parent)) {
+				toplevel = parent;
+				parent = panel_toplevel_get_attach_toplevel (toplevel);
+			}
+
 			panel_toplevel_hide (toplevel, FALSE, -1);
+		}
 	}
 }
 
@@ -246,6 +255,9 @@ drag_data_received_cb (GtkWidget        *widget,
 
 	envp = panel_make_environment_for_screen (screen, NULL);
 
+	if (panel_global_config_get_enable_animations ())
+		xstuff_zoom_animate (widget, NULL);
+	
 	gnome_desktop_item_drop_uri_list_with_env (launcher->ditem,
 						   (const char *)selection_data->data,
 						   0 /* flags */,
@@ -634,9 +646,23 @@ properties_close_callback(GtkWidget *widget, gpointer data)
 }
 
 static void
-launcher_changed (GtkObject *dedit, gpointer data)
+launcher_changed (GObject *dedit, gpointer data)
 {
-	Launcher *launcher = data;
+	Launcher         *launcher;
+	GnomeDesktopItem *new_ditem;
+	const char       *old_exec;
+	const char       *new_exec;
+
+	launcher = (Launcher *) data;
+	new_ditem = gnome_ditem_edit_get_ditem (GNOME_DITEM_EDIT (dedit));
+
+	old_exec = gnome_desktop_item_get_string (launcher->ditem,
+						  GNOME_DESKTOP_ITEM_EXEC);
+	new_exec = gnome_desktop_item_get_string (new_ditem,
+						  GNOME_DESKTOP_ITEM_EXEC);
+
+	if (!old_exec || !new_exec || strcmp (old_exec, new_exec))
+		gnome_desktop_item_clear_attr (new_ditem, "StartupNotify");
 
 	properties_apply (launcher);
 }
@@ -953,10 +979,10 @@ really_add_launcher (GtkWidget *dialog, int response, gpointer data)
 							 TRUE,
 						         _("Cannot create launcher"),
 						         _("You have to specify a name."));
-			g_signal_connect_swapped (G_OBJECT (err_dialog),
+			g_signal_connect_swapped (G_OBJECT (dialog),
 						  "destroy",
-						   G_CALLBACK (panel_pop_window_busy),
-						   G_OBJECT (dialog));
+						   G_CALLBACK (gtk_widget_destroy),
+						   G_OBJECT (err_dialog));
 			return;
 		}
 		
@@ -971,10 +997,10 @@ really_add_launcher (GtkWidget *dialog, int response, gpointer data)
 							 TRUE,
 							 _("Cannot create launcher"),
 							 _("You have to specify a valid URL or command."));
-			g_signal_connect_swapped (G_OBJECT (err_dialog),
+			g_signal_connect_swapped (G_OBJECT (dialog),
 						  "destroy",
-						  G_CALLBACK (panel_pop_window_busy),
-						  G_OBJECT (dialog));
+						  G_CALLBACK (gtk_widget_destroy),
+						  G_OBJECT (err_dialog));
 			return;
 		}
 
