@@ -430,7 +430,13 @@ panel_menu_bar_append_gtk_bookmarks (PanelMenuBar *menubar,
 	//dialog if there's a bookmarks to sftp://something?
 	for (i = 0; lines[i]; i++) {
 		if (lines[i][0] && !g_hash_table_lookup (table, lines[i])) {
-			uri = gnome_vfs_uri_new (lines[i]);
+			char *unescaped_uri;
+
+			unescaped_uri = gnome_vfs_unescape_string (lines[i],
+								   "");
+			uri = gnome_vfs_uri_new (unescaped_uri);
+			g_free (unescaped_uri);
+
 			if (!gnome_vfs_uri_exists (uri)) {
 				gnome_vfs_uri_unref (uri);
 				continue;
@@ -453,7 +459,9 @@ panel_menu_bar_append_gtk_bookmarks (PanelMenuBar *menubar,
 		setup_menu_item_with_icon (item, panel_menu_icon_get_size (),
 					   "stock_bookmark", NULL,
 					   _("Bookmarks"), TRUE);
+
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		gtk_widget_show (item);
 
 		add_menu = create_empty_menu ();
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), add_menu);
@@ -530,6 +538,7 @@ panel_menu_bar_append_volumes (PanelMenuBar *menubar,
 			item = gtk_menu_item_new_with_label (_("Removable Media"));
 
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		gtk_widget_show (item);
 
 		add_menu = create_empty_menu ();
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), add_menu);
@@ -568,6 +577,7 @@ static GtkWidget *
 panel_menu_bar_create_places_menu (PanelMenuBar *menubar)
 {
 	GtkWidget *places_menu;
+	GtkWidget *item;
 
 	places_menu = panel_create_menu ();
 
@@ -578,8 +588,14 @@ panel_menu_bar_create_places_menu (PanelMenuBar *menubar)
 				    DESKTOP_IS_HOME_DIR_KEY,
 				    NULL))
 		panel_menu_bar_append_place_item (menubar, "gnome-fs-desktop",
-						  _("Desktop"),
-						  _("Desktop directory"),
+						  /* Translators: Desktop is
+						   * used here as in "Desktop
+						   * Folder" (this is not the
+						   * Desktop environment). Do
+						   * not keep "Desktop Folder|"
+						   * in the translation */
+						  Q_("Desktop Folder|Desktop"),
+						  _("Open the desktop as a folder"),
 						  places_menu,
 						  G_CALLBACK (activate_uri),
 						  "Desktop");
@@ -595,11 +611,13 @@ panel_menu_bar_create_places_menu (PanelMenuBar *menubar)
 	panel_menu_bar_append_from_desktop (places_menu,
 					    "network-scheme.desktop");
 	panel_menu_bar_append_volumes (menubar, places_menu, TRUE);
-#if 0
-	item = menu_create_action_item (PANEL_ACTION_CONNECT_SERVER);
-	if (item != NULL)
-		gtk_menu_shell_append (GTK_MENU_SHELL (places_menu), item);
-#endif
+
+	if (panel_is_program_in_path ("nautilus-connect-server")) {
+		item = menu_create_action_item (PANEL_ACTION_CONNECT_SERVER);
+		if (item != NULL)
+			gtk_menu_shell_append (GTK_MENU_SHELL (places_menu),
+					       item);
+	}
 
 	add_menu_separator (places_menu);
 
@@ -762,7 +780,10 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar),
 			       menubar->priv->places_item);
 
-	menubar->priv->desktop_item = gtk_menu_item_new_with_label (_("Desktop"));
+	/* Translators: Desktop is used here as in "Desktop Environment" (this
+	 * is not the Desktop folder). Do not keep "Desktop Environment|" in
+	 * the translation. */
+	menubar->priv->desktop_item = gtk_menu_item_new_with_label (Q_("Desktop Environment|Desktop"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menubar->priv->desktop_item),
 				   menubar->priv->desktop_menu);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menubar),
