@@ -155,7 +155,7 @@ recent_documents_clear_cb (GtkMenuItem    *menuitem,
 						      _("Clear the Recent Documents list?"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (clear_recent_dialog),
 						  _("If you clear the Recent Documents list, you clear the following:\n\n"
-						    "\342\200\242 All items from the Actions \342\206\222 Recent Documents menu item.\n"
+						    "\342\200\242 All items from the Places \342\206\222 Recent Documents menu item.\n"
 						    "\342\200\242 All items from the recent documents list in all applications."));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (clear_recent_dialog),
@@ -232,9 +232,9 @@ panel_recent_append_documents_menu (GtkWidget *top_menu)
 	
 	/* a model that shows the global recent doc list */
 	model = egg_recent_model_new (EGG_RECENT_MODEL_SORT_MRU);
-	g_signal_connect (model, "changed",
-			  G_CALLBACK (panel_recent_model_changed_cb),
-			  menu_item);
+	g_signal_connect_object (model, "changed",
+				 G_CALLBACK (panel_recent_model_changed_cb),
+				 menu_item, 0);
 
 	view = egg_recent_view_gtk_new (menu, NULL);
 
